.. ref-sdb

=============
SDB Reference
=============

In addition to what is seen below, boto includes an abstraction
layer for SimpleDB that may be used:

* :doc:`SimpleDB DB <sdb_db>` (Maintained, but little documentation)

boto.sdb
--------

.. automodule:: boto.sdb
   :members:   
   :undoc-members:

boto.sdb.connection
-------------------

.. automodule:: boto.sdb.connection
   :members:   
   :undoc-members:

boto.sdb.domain
---------------

.. automodule:: boto.sdb.domain
   :members:   
   :undoc-members:

boto.sdb.item
-------------

.. automodule:: boto.sdb.item
   :members:   
   :undoc-members:

boto.sdb.queryresultset
-----------------------

.. automodule:: boto.sdb.queryresultset
   :members:   
   :undoc-members:
